@@ -1,5 +1,4 @@
 pamr.makeclasses <- function(data,  sort.by.class = FALSE, ...) {
-  require(cluster)
   as.matrix.dist <- function (x)  {
     size <- attr(x, "Size")
     df <- matrix(0, size, size)
@@ -51,7 +50,7 @@ pamr.makeclasses <- function(data,  sort.by.class = FALSE, ...) {
     }
   }
   hc <- hclust(as.dist(dd), ...)
-  plot.hclust(hc, labels = labs)
+  plclust(hc, labels = labs)
   aa <- vector("list", 100)
   go <- TRUE
   i <- 0
@@ -125,7 +124,7 @@ pamr.makeclasses <- function(data,  sort.by.class = FALSE, ...) {
   labs2 <- as.character(newy)
   labs2[labs2 == "NA"] <- ""
   par(col = 1, cex = 1)
-  plot.hclust(hc, labels = labs2)
+  plclust(hc, labels = labs2)
   return(as.factor(newy))
 }
 
